/*
 *  soapui, copyright (C) 2006 eviware.com 
 *
 *  SoapUI is free software; you can redistribute it and/or modify it under the 
 *  terms of the GNU Lesser General Public License as published by the Free Software Foundation; 
 *  either version 2.1 of the License, or (at your option) any later version.
 *
 *  SoapUI is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without 
 *  even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
 *  See the GNU Lesser General Public License for more details at gnu.org.
 */

package com.eviware.soapui.maven2;

import java.io.File;

import org.apache.maven.plugin.AbstractMojo;
import org.apache.maven.plugin.MojoExecutionException;
import org.apache.maven.plugin.MojoFailureException;

import com.eviware.soapui.SoapUI;
import com.eviware.soapui.tools.SoapUILoadTestRunner;

/**
 * Runs soapUI loadtests
 * 
 * @goal loadtest
 */

public class LoadTestMojo extends AbstractMojo
{
	public void execute() throws MojoExecutionException, MojoFailureException
	{
		if( projectFile == null )
		{
			throw new MojoExecutionException("soapui-project-file setting is required" );
		}

		if( !new File(projectFile).exists() )
		{
			throw new MojoExecutionException("soapui-project-file [" + projectFile + "] is not found" );
		}
		
		SoapUILoadTestRunner runner = new SoapUILoadTestRunner( 
					"soapUI " + SoapUI.SOAPUI_VERSION + " Maven2 LoadTest Runner");
		runner.setProjectFile( projectFile );
		
		if( endpoint != null )
			runner.setEndpoint( endpoint );
		
		if( testSuite != null )
			runner.setTestSuite( testSuite );
		
		if( testCase != null )
			runner.setTestCase( testCase );
		
		if( loadTest != null )
			runner.setLoadTest( loadTest );
		
		if( username != null )
			runner.setUsername( username );
		
		if( password != null )
			runner.setPassword( password );
		
		if( wssPasswordType != null )
			runner.setWssPasswordType( wssPasswordType );
		
		if( domain != null )
			runner.setDomain( domain );
		
		if( host != null )
			runner.setHost( host );
		
		if( outputFolder != null )
			runner.setOutputFolder( outputFolder );
		
		runner.setPrintReport( printReport );
		
		if( settingsFile != null )
			SoapUI.initSettings( settingsFile );
		
		try
		{
			runner.run();
		}
		catch (Throwable e)
		{
			getLog().error( e.toString() );
			throw new MojoFailureException( this, "SoapUI LoadTest(s) failed", e.getMessage() ); 
		}		
	}
	
	/**
    * The soapUI project file to test with
    *
    * @parameter expression="${soapui.projectFile}"    
    * 	default-value="${project.artifactId}-soapui-project.xml"
    */
	
   private String projectFile;
   
   /**
    * The TestSuite to run 
    *
    * @parameter expression="${soapui.testsuite}"    
    */
	
   private String testSuite;
   
   /**
    * The TestCase to run 
    *
    * @parameter expression="${soapui.testcase}"    
    */
	
   private String testCase;
   
   /**
    * The LoadTest to run 
    *
    * @parameter expression="${soapui.loadtest}"    
    */
	
   private String loadTest;
   
   /**
    * The username to use for authentication challenges
    *
    * @parameter expression="${soapui.username}"    
    */
	
   private String username;
   
   /**
    * The password to use for authentication challenges
    *
    * @parameter expression="${soapui.password}"    
    */
	
   private String password;
   
   /**
	 * The WSS password-type to use for any authentications. Setting this will result
	 * in the addition of WS-Security UsernamePassword tokens to any outgoing request containing
	 * the specified username and password. Set to either 'Text' or 'Digest'
	 *  
    * @parameter expression="${soapui.wssPasswordType}"    
	 */
	
   private String wssPasswordType;
   
   /**
    * The domain to use for authentication challenges
    *
    * @parameter expression="${soapui.domain}"    
    */
	
   private String domain;
   
   /**
    * The host to use for requests
    *
    * @parameter expression="${soapui.host}"    
    */
	
   private String host;
   
   /**
    * Overrides the endpoint to use for requests
    *
    * @parameter expression="${soapui.endpoint}"    
    */
	
   private String endpoint;
   
   /**
    * Sets the output folder for reports
    *
    * @parameter expression="${soapui.outputFolder}"    
    */
	
   private String outputFolder;
   
   /**
    * Turns on printing of reports
    *
    * @parameter 
    */
	
   private boolean printReport;
   
   /**
    * Specifies soapUI settings file to use
    *
    * @parameter expression="${soapui.settingsFile}"    
    * */
	
   private String settingsFile;
}
